summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMike Kaganski <mike.kaganski@collabora.com>2022-04-11 10:02:49 +0300
committerMike Kaganski <mike.kaganski@collabora.com>2022-04-11 10:35:11 +0200
commitb9caa1c0732868903dac7ba70c4092d0213235b6 (patch)
tree92e06336b165096f16c72f70df69c07dc3fc40b0 /include
parentbdc4819a37e16e12ea74531b3413f8bd8693479e (diff)
Replace references to rtl_ImplIsWhitespace with implIsWhitespace
... after commit 57f22d9b1a4e1cd161a35c8e4c390661db981d2c. Change-Id: I4232adc805593575d0bb7549b40ad35308829261 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/132805 Tested-by: Jenkins Reviewed-by: Mike Kaganski <mike.kaganski@collabora.com>
Diffstat (limited to 'include')
-rw-r--r--include/o3tl/string_view.hxx12
-rw-r--r--include/rtl/ustring.h2
-rw-r--r--include/rtl/ustring.hxx2
3 files changed, 8 insertions, 8 deletions
diff --git a/include/rtl/ustring.h b/include/rtl/ustring.h
index 16ec6ed5931c..2371d9a5e8d7 100644
--- a/include/rtl/ustring.h
+++ b/include/rtl/ustring.h
@@ -2094,7 +2094,7 @@ SAL_DLLPUBLIC void SAL_CALL rtl_uString_newToAsciiUpperCase(
The new string results from removing all characters with values less than
or equal to 32 (the space character), and also Unicode General Punctuation
area Space and some Control characters, form both ends of str (see
- rtl_ImplIsWhitespace).
+ implIsWhitespace).
This function cannot be used for language-specific conversion. The new
string does not necessarily have a reference count of 1 (in cases where
diff --git a/include/rtl/ustring.hxx b/include/rtl/ustring.hxx
index c530f1702a81..ca061328d5a4 100644
--- a/include/rtl/ustring.hxx
+++ b/include/rtl/ustring.hxx
@@ -2652,7 +2652,7 @@ public:
All characters that have codes less than or equal to
32 (the space character), and Unicode General Punctuation area Space
and some Control characters are considered to be white space (see
- rtl_ImplIsWhitespace).
+ implIsWhitespace).
If the string doesn't contain white spaces at both ends,
then the new string is assigned with str.
diff --git a/include/o3tl/string_view.hxx b/include/o3tl/string_view.hxx
index c09352145440..2a33885ce166 100644
--- a/include/o3tl/string_view.hxx
+++ b/include/o3tl/string_view.hxx
@@ -317,8 +317,8 @@ constexpr bool ends_with(std::u16string_view sv, std::u16string_view x,
namespace internal
{
-// copy of rtl_ImplIsWhitespace from sal/rtl/strimp.cxx
-inline bool rtl_ImplIsWhitespace(sal_Unicode c)
+// copy of implIsWhitespace from sal/rtl/strtmpl.hxx
+inline bool implIsWhitespace(sal_Unicode c)
{
/* Space or Control character? */
if ((c <= 32) && c)
@@ -346,10 +346,10 @@ inline std::u16string_view trim(std::u16string_view str)
sal_Int32 nPostSpaces = 0;
sal_Int32 nIndex = str.size() - 1;
- while ((nPreSpaces < nLen) && internal::rtl_ImplIsWhitespace(*(str.data() + nPreSpaces)))
+ while ((nPreSpaces < nLen) && internal::implIsWhitespace(*(str.data() + nPreSpaces)))
nPreSpaces++;
- while ((nIndex > nPreSpaces) && internal::rtl_ImplIsWhitespace(*(str.data() + nIndex)))
+ while ((nIndex > nPreSpaces) && internal::implIsWhitespace(*(str.data() + nIndex)))
{
nPostSpaces++;
nIndex--;
@@ -368,10 +368,10 @@ inline std::string_view trim(std::string_view str)
sal_Int32 nPostSpaces = 0;
sal_Int32 nIndex = str.size() - 1;
- while ((nPreSpaces < nLen) && internal::rtl_ImplIsWhitespace(*(str.data() + nPreSpaces)))
+ while ((nPreSpaces < nLen) && internal::implIsWhitespace(*(str.data() + nPreSpaces)))
nPreSpaces++;
- while ((nIndex > nPreSpaces) && internal::rtl_ImplIsWhitespace(*(str.data() + nIndex)))
+ while ((nIndex > nPreSpaces) && internal::implIsWhitespace(*(str.data() + nIndex)))
{
nPostSpaces++;
nIndex--;